/*jshint node:true*/
var inquirer = require("inquirer"),
	fs = require('fs'),
	_ = require('underscore'),
	mkdirp = require('mkdirp'),
	path = require('path'),
	sifeConfig;


// Here is the story:
//
// what namespace ?
// - ef
// - pure
//
// name of component ?
// >foo
//
// need css/foo.css ?
//
// need html/foo.hbs ?
//
// need config.json ?
//




var start = function(sifeConfig){

	var namespaces = _.filter(
		fs.readdirSync(sifeConfig.sources.components),
		function(ns){
			if(sifeConfig.sources.componentsOptions && sifeConfig.sources.componentsOptions[ns] && sifeConfig.sources.componentsOptions[ns].cssOnly){
				return false;
			}
			if(path.parse(ns).ext){
				return false;
			}
			return true;
		}
	);

	var getComponentPath = function(answers){
		return sifeConfig.sources.components+'/'+answers.namespace+'/'+(answers.atomicType ? answers.atomicType+'/' : '')+answers.componentName;
	};


	var questions = [
		{
			name: 'namespace',
			message: 'In which namespace ?',
			type: 'list',
			choices: namespaces
		},
		{
			// additional question if namespace is "atomic"
			when: function(answers){
				if(sifeConfig.sources.componentsOptions && sifeConfig.sources.componentsOptions[answers.namespace] && sifeConfig.sources.componentsOptions[answers.namespace].atomic){
					return true;
				}
				return false;
			},
			name: 'atomicType',
			type: 'list',
			message: 'What atomic entity is it ?',
			choices: function(answers){
				return fs.readdirSync(sifeConfig.sources.components+'/'+answers.namespace);
			}
		},
		{
			name: 'componentName',
			message: 'Name of component',
			type: 'input'
		},
		{
			// stop everything if component already exist
			when: function(answers){
				var path = getComponentPath(answers);
				var stats;

				try{
					stats = fs.statSync(path);
				}catch(err){
					stats = false;
				}

				if(stats && (stats.isFile() || stats.isDirectory())){
					console.log(path+' already exists');
					process.exit();
				}
			}
		},
		{
			name:'generateCSS',
			type:'confirm',
			message:function(answers){
				return 'need css/'+answers.componentName+'.css ?';
			}
		},
		{
			name:'generateHTML',
			type:'confirm',
			message:function(answers){
				return 'need html/'+answers.componentName+'.hbs ?';
			}
		},
		{
			name:'generateConfig',
			type:'confirm',
			message:'need config.json ?'
		}
	];



	inquirer.prompt(questions, function(answers){
		var componentPath = getComponentPath(answers);
		// create base directory
		mkdirp.sync(componentPath);

		mkdirp.sync(componentPath+'/data/');
		fs.writeFileSync(componentPath+'/standard.json', '{\n\t\n}');

		if(answers.generateCSS){
			mkdirp.sync(componentPath+'/css/');
			fs.writeFileSync(componentPath+'/css/'+answers.componentName+'.css', '');
		}

		if(answers.generateHTML){
			mkdirp.sync(componentPath+'/html/');
			fs.writeFileSync(componentPath+'/html/'+answers.componentName+'.hbs', '');
		}

		if(answers.generateConfig){
			fs.writeFileSync(componentPath+'/config.json', '{\n\t\n}');
		}

		console.log('✨ Done!✨');

	});
};

module.exports.start = start;


