/*jshint node:true*/
var _ = require('underscore'),
	gruntHelper = require('./gruntHelper.js'),
	componentBuilder = require('./componentBuilder.js'),
	themeBuilder = require('./themeBuilder.js'),
	fs = require('fs'),
	path = require('path');

module.exports = {

	init: function(conf) {
		this.conf = conf;
	},

	build: function(){
		var conf = this.conf;
		var taskList = [];
		gruntHelper.reset();

		// grid
		if (conf.build.grid) {

			gruntHelper.pure_grids.init(conf.build.grid, conf.output.css.components);
			taskList.push('pure_grids');

			// replace __grid__ in build.css.base
			conf.build.css.base = gruntHelper.pure_grids.insertGridPaths(conf.build.css.base, conf.output.css.components);
			conf.build.css['theme-base'] = gruntHelper.pure_grids.insertGridPaths(conf.build.css['theme-base'], conf.output.css.components);

		}

		// base css
		gruntHelper.clean.add('basecss', this.getOutputPath('css', 'base'));
		taskList.push('clean:basecss');
		gruntHelper.concat.add('basecss', this.getOutputPath('css', 'base'), conf.build.css.base);
		taskList.push('concat:basecss');
		gruntHelper.concat.add('theme-basecss', conf.output.css.base + '/theme-base.css', conf.build.css['theme-base']);
		taskList.push('concat:theme-basecss');

		// components css/js
		gruntHelper.clean.add('components', this.getOutputPath('css', 'components'));
		taskList.push('clean:components');

		componentBuilder.init(conf);
		componentBuilder.createTasks(gruntHelper, 'components', taskList);
		taskList.push('concat:components');


		// themes css/js
		themeBuilder.init(conf);
		themeBuilder.createTasks(gruntHelper, 'themes');
		taskList.push('concat:themes');


		// styleguide/components JST
		gruntHelper.handlebars.init(conf);
		gruntHelper.handlebars.add('styleguide_components', conf.output.jst + '/_all_components.js', [conf.sources.components + '/**/*.hbs'], {partialsPathRegex: /.*/, components:true});
		taskList.push('handlebars:styleguide_components');


		// styleguide/themes JST
		gruntHelper.handlebars.add('styleguide_themes', conf.output.jst + '/_all_themes.js', [conf.sources.themes + '/**/*.hbs'], {partialsPathRegex: /partials\//, themes:true});
		taskList.push('handlebars:styleguide_themes');

		// concat all handlebars_helpers for styleguide
		gruntHelper.concat.add('styleguide_hbs_helpers', conf.output.js + '/handlebars-helpers.js', conf.sources.handlebars_helpers + '/*.js');
		taskList.push('concat:styleguide_hbs_helpers');


		// rework css
		gruntHelper.loadReworkTask([
			path.join(conf.output.css.base, 'base.css'), // do not rework theme-base.css
			path.join(conf.output.css.components, '**/*.css'),
			path.join(conf.output.css.themes, '**/*.css')
		]);
		taskList.push('rework');


		// cleanup all temp files
		gruntHelper.clean.add('tempfiles', [
			conf.output.css.base + '/__*.css',
			conf.output.css.components + '/__*.css',
			conf.output.css.themes + '/__*.css'
		]);
		taskList.push('clean:tempfiles');


		gruntHelper.runTasks(taskList);

	},

	transpile: function(){
		var conf = this.conf;
		gruntHelper.reset();
		var taskList = [];

		gruntHelper.loadTranspilerTask(require(path.resolve(conf.sources.transpiler_task)));
		taskList.push('transpile');

		gruntHelper.setGruntConfig('transpile', conf.build.transpile);

		gruntHelper.runTasks(taskList);
	},

	getOutputPath: function(type, name) {
		return this.conf.output[type][name] + '/' + name + '.css';
	}
};
